============================
django-vintage v |version|
============================

About
=====

The primary goals for Django Vintage are to:

* Archive pages from an old site to make them available
* Allow pointers to new resources that replace these
* Keep per-page metadata for search engines
* Use existing URL structure so redirecting from old site to archive is easy


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   templates
   metadata
   reference/index
